<?php
$login_page = get_field('login_side', 'option');
$user_created = false;

// Check if the form is submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['username'], $_POST['password'], $_POST['password_check'])) {
    $username = sanitize_text_field($_POST['username']);
    $password = $_POST['password'];
    $password_check = $_POST['password_check'];
    $email = sanitize_email($_POST['email']);
    $firstname = sanitize_text_field($_POST['firstname']);
    $lastname = sanitize_text_field($_POST['lastname']);
    $organization = sanitize_text_field($_POST['organization']);
    $country = sanitize_text_field($_POST['country']);
    $send_credentials = isset($_POST['accept_credentials']) && $_POST['accept_credentials'] === 'true';

    // Validate required fields and check if passwords match
    if ($username && $email && $firstname && $lastname && $password && $organization && ($password === $password_check)) {
        $user_id = username_exists($username);
        if (!$user_id && email_exists($email) == false) {
            // Create the user
            $user_id = wp_create_user($username, $password, $email);
            if (!is_wp_error($user_id)) {
                // Set the user's firstname and lastname
                wp_update_user([
                    'ID' => $user_id,
                    'first_name' => $firstname,
                    'last_name' => $lastname,
                    // Add additional user meta such as 'organization' if needed
                ]);

                // Add the organization ACF field
                update_field('organization', $organization, 'user_' . $user_id);
                update_field('country', $country, 'user_' . $user_id);

                // Optionally send credentials email
                if ($send_credentials) {
                    $message = "Welcome to EnergyPLAN!\n\n";
                    $message .= "You have signed up with the username: $username \n\n";
                    $message .= "You can log in to your account here: $login_page \n\n";
                    $message .= "Best regards\n";
                    $message .= "EnergyPLAN\n\n";
                    wp_mail($email, 'Welcome to EnergyPLAN', $message);
                }

                $user_created = true;

                // Redirect or success message
                echo '<p class="text-[#859F3F] mb-4">User created successfully! </br><a class="green-btn mt-4" href="' . $login_page . '">Go to log in</a></p>';
            } else {
                echo '<p class="text-red-500 mb-4">Error: ', $user_id->get_error_message(), '</p>';
            }
        } else {
            echo '<p class="text-red-500 mb-4">User or email already exists.</p>';
        }
    } else {
        echo '<p class="text-red-500 mb-4">Invalid form data.</p>';
    }
}
?>

<?php $terms = get_field('opret_bruger_betingelser', 'option'); ?>

<div class="grid gap-10 grid-cols-6 mb-24">
    <?php if (isset($_GET['accept_terms'])) : ?>

    <?php if(!$user_created) : ?>

        <?php $countries = ["Afghanistan","Albania","Algeria","Andorra","Angola","Anguilla","Antigua &amp; Barbuda","Argentina","Armenia","Aruba","Australia","Austria","Azerbaijan","Bahamas","Bahrain","Bangladesh","Barbados","Belarus","Belgium","Belize","Benin","Bermuda","Bhutan","Bolivia","Bosnia &amp; Herzegovina","Botswana","Brazil","British Virgin Islands","Brunei","Bulgaria","Burkina Faso","Burundi","Cambodia","Cameroon","Cape Verde","Cayman Islands","Chad","Chile","China","Colombia","Congo","Cook Islands","Costa Rica","Cote D Ivoire","Croatia","Cruise Ship","Cuba","Cyprus","Czech Republic","Denmark","Djibouti","Dominica","Dominican Republic","Ecuador","Egypt","El Salvador","Equatorial Guinea","Estonia","Ethiopia","Falkland Islands","Faroe Islands","Fiji","Finland","France","French Polynesia","French West Indies","Gabon","Gambia","Georgia","Germany","Ghana","Gibraltar","Greece","Greenland","Grenada","Guam","Guatemala","Guernsey","Guinea","Guinea Bissau","Guyana","Haiti","Honduras","Hong Kong","Hungary","Iceland","India","Indonesia","Iran","Iraq","Ireland","Isle of Man","Israel","Italy","Jamaica","Japan","Jersey","Jordan","Kazakhstan","Kenya","Kuwait","Kyrgyz Republic","Laos","Latvia","Lebanon","Lesotho","Liberia","Libya","Liechtenstein","Lithuania","Luxembourg","Macau","Macedonia","Madagascar","Malawi","Malaysia","Maldives","Mali","Malta","Mauritania","Mauritius","Mexico","Moldova","Monaco","Mongolia","Montenegro","Montserrat","Morocco","Mozambique","Namibia","Nepal","Netherlands","Netherlands Antilles","New Caledonia","New Zealand","Nicaragua","Niger","Nigeria","Norway","Oman","Pakistan","Palestine","Panama","Papua New Guinea","Paraguay","Peru","Philippines","Poland","Portugal","Puerto Rico","Qatar","Reunion","Romania","Russia","Rwanda","Saint Pierre &amp; Miquelon","Samoa","San Marino","Satellite","Saudi Arabia","Senegal","Serbia","Seychelles","Sierra Leone","Singapore","Slovakia","Slovenia","South Africa","South Korea","Spain","Sri Lanka","St Kitts &amp; Nevis","St Lucia","St Vincent","St. Lucia","Sudan","Suriname","Swaziland","Sweden","Switzerland","Syria","Taiwan","Tajikistan","Tanzania","Thailand","Timor L'Este","Togo","Tonga","Trinidad &amp; Tobago","Tunisia","Turkey","Turkmenistan","Turks &amp; Caicos","Uganda","Ukraine","United Arab Emirates","United Kingdom","United States","Uruguay","Uzbekistan","Venezuela","Vietnam","Virgin Islands (US)","Yemen","Zambia","Zimbabwe"]; ?>

        <form class="col-span-full lg:col-span-3" action="<?php echo $_SERVER['REQUEST_URI']; ?>" method="post" x-data="{ password: '', password_check: '', passwordsMatch() { return this.password === this.password_check; } }">
            <p>
                <label for="username"><?php echo _e('Username', "EnergyPLAN") ?></label>
                <input type="text" name="username" id="create-account-username" required>
            </p>

            <p>
                <label for="firstname"><?php echo _e('Firstname', "EnergyPLAN") ?></label>
                <input type="text" name="firstname" id="create-account-firstname" required>
            </p>
            <p>
                <label for="lastname"><?php echo _e('Lastname', "EnergyPLAN") ?></label>
                <input type="text" name="lastname" id="create-account-lastname" required>
            </p>
            <p>
                <label for="email"><?php echo _e('E-mail', "EnergyPLAN") ?></label>
                <input type="email" name="email" id="create-account-email" required>
            </p>
            <p>
                <label for="country"><?php echo _e('Country', "EnergyPLAN") ?></label>
                <select name="country" id="country-select">
                    <?php foreach ($countries as $country) : ?>
                        <option value="<?php echo $country ?>"><?php echo $country ?></option>
                    <?php endforeach; ?>
                </select>
            </p>
            <p>
                <label for="organization"><?php echo _e('Organization', "EnergyPLAN") ?></label>
                <input type="text" name="organization" id="create-account-organization" required>
            </p>
            <p>
                <label for="password"><?php echo _e('Choose password', "EnergyPLAN") ?></label>
                <input type="password" name="password" id="create-account-password" minlength="8" required x-model="password">
            </p>
            <p>
                <label for="password_check"><?php echo _e('Repeat password', "EnergyPLAN") ?></label>
                <input type="password" name="password_check" id="create-account-password_check" required x-model="password_check">
                <template x-if="password && password_check && !passwordsMatch()">
                    <p class="text-red-500"><?php _e('Passwords do not match.', "EnergyPLAN") ?></p>
                </template>
            </p>
            <p class="mt-8 flex">
                <input class="me-3" type="checkbox" id="credentials" name="accept_credentials" value="true" required>
                <label for="accept_credentials"> <?php _e('Send these credentials via email.', 'EnergyPLAN') ?></label><br>
            </p>
            <p>
                <input class="blue-btn mt-8" type="submit" value="<?php _e('Create my account', 'EnergyPLAN') ?>" :disabled="!passwordsMatch()">
            </p>
        </form>
    <?php endif; ?>
    <?php else: ?>
        <div class="col-span-full lg:col-span-5">
            <p class="mb-8"><?php echo _e('Please read and accept out terms.', 'EnergyPLAN') ?></p>
            <?php echo $terms ?>
            <div class="mt-16">
                <form action="" method="get">
                    <p class="flex">
                        <input class="me-3" type="checkbox" id="accept" name="accept_terms" value="true" required>
                        <label for="accept"> <?php _e('I hereby accept', 'EnergyPLAN') ?></label><br>
                    </p>
                    <input class="blue-btn mt-8" type="submit" value="<?php _e('Continue Registration', 'EnergyPLAN') ?>"/>
                </form>
            </div>
        </div>
    <?php endif; ?>
</div>