<?php
$args = array(
    'role'    => 'subscriber',
    'orderby' => 'display_name',
    'order'   => 'ASC'
);

$users = get_users($args);

$users_by_country = array();

// Loop through users
foreach ($users as $user) {
    // Get the country field from ACF for the user
    $country = get_field('country', 'user_' . $user->ID);

    // Get user's first name, last name, and email
    $first_name = get_user_meta($user->ID, 'first_name', true);
    $last_name = get_user_meta($user->ID, 'last_name', true);
    $email = $user->user_email;

    // Group users by country
    if (!empty($country)) {
        $users_by_country[$country][] = array(
            'first_name' => $first_name,
            'last_name'  => $last_name,
            'email'      => $email,
            'user'       => $user
        );
    }
}

ksort($users_by_country);
?>
<div class="mt-10 grid grid-cols-6 gap-x-10">
    <div class="<?php echo 'col-span-full lg:col-span-5'?>">
        <?php
        // Loop through the countries and list users
        foreach ($users_by_country as $country => $users_info) : ?>
            <div class="col-span-full mb-[5px]">
                <details class="bg-[#ECECEC] border border-[#C0C6CD] rounded-md col-span-full peer flex cursor-pointer">
                    <summary class="w-full py-[15px] flex items-center px-[20px]">
                        <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" width="24" height="24"><path fill="#2B3B4C" d="M12 22c-1.3833 0-2.68333-.2625-3.9-.7875-1.21667-.525-2.275-1.2375-3.175-2.1375-.9-.9-1.6125-1.9583-2.1375-3.175C2.2625 14.6833 2 13.3833 2 12c0-1.3833.2625-2.68333.7875-3.9.525-1.21667 1.2375-2.275 2.1375-3.175.9-.9 1.95833-1.6125 3.175-2.1375C9.31667 2.2625 10.6167 2 12 2c1.3833 0 2.6833.2625 3.9.7875 1.2167.525 2.275 1.2375 3.175 2.1375.9.9 1.6125 1.95833 2.1375 3.175.525 1.21667.7875 2.5167.7875 3.9 0 1.3833-.2625 2.6833-.7875 3.9-.525 1.2167-1.2375 2.275-2.1375 3.175-.9.9-1.9583 1.6125-3.175 2.1375-1.2167.525-2.5167.7875-3.9.7875Zm-1-2.05V18c-.55 0-1.02083-.1958-1.4125-.5875C9.19583 17.0208 9 16.55 9 16v-1l-4.8-4.8c-.05.3-.09583.6-.1375.9-.04167.3-.0625.6-.0625.9 0 2.0167.6625 3.7833 1.9875 5.3 1.325 1.5167 2.99583 2.4 5.0125 2.65Zm6.9-2.55c.3333-.3667.6333-.7625.9-1.1875.2667-.425.4875-.8667.6625-1.325.175-.4583.3083-.9292.4-1.4125C19.9542 12.9917 20 12.5 20 12c0-1.6333-.4542-3.125-1.3625-4.475C17.7292 6.175 16.5167 5.2 15 4.6V5c0 .55-.1958 1.02083-.5875 1.4125C14.0208 6.80417 13.55 7 13 7h-2v2c0 .28333-.0958.52083-.2875.7125C10.5208 9.90417 10.2833 10 10 10H8v2h6c.2833 0 .5208.0958.7125.2875.1917.1917.2875.4292.2875.7125v3h1c.4333 0 .825.1292 1.175.3875.35.2583.5917.5958.725 1.0125Z"/></svg>
                        <span class="px-[30px] text-[16px]"><?php echo esc_html($country) ?></span>
                    </summary>
                </details>
                <div class="w-full grid grid-rows-[0fr] bg-[#ECECEC] transition-[grid-template-rows] border-b border-b-[#C0C6CD] invisible border-x border-x-[#C0C6CD] rounded-b-md peer-open:bg-[#FAFAFA] peer-open:grid-rows-1 peer-open:visible overflow-hidden">
                    <div class="overflow-hidden col-span-full">
                        <div class="px-8 py-4 lg:px-[76px] lg:py-[40px]">
                            <?php foreach ($users_info as $info) : ?>
                                <div class="block sm:flex mb-4">
                                    <div class="sm:w-5/12 lg:w-4/12"><?php echo esc_html($info['first_name']) . ' ' . esc_html($info['last_name']) ?></div>
                                    <div class=" sm:w-7/12 sm:ml-4 lg:w-8/12"><a href="mailto:<?php echo esc_html($info['email']) ?>"><?php echo esc_html($info['email']) ?></a></div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>