<?php
global $pagenow;
$login_page = get_field('login_side', 'option');
$message = false;
$show_form = true;

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['password'], $_POST['password_check'])) {
    require_once ABSPATH . 'wp-load.php'; // Ensures WordPress functions are loaded

    $password = $_POST['password'];
    $password_check = $_POST['password_check'];

    // Get these from the URL
    $key = isset($_GET['key']) ? $_GET['key'] : '';
    $login = isset($_GET['login']) ? $_GET['login'] : '';

    if ($password !== $password_check) {
        echo '<div class="error"><p>' . __('Passwords do not match. Please try again.', 'EnergyPLAN') . '</p></div>';
    } else {
        $user = check_password_reset_key($key, $login);

        if (is_wp_error($user)) {
            $message = '<div class="error text-red-500 mb-4"><p>' . 'Error: ' . $user->get_error_message() . '</p></div>';
        } else {
            // Everything's good, change the password
            wp_set_password($password, $user->ID);
            // Redirect to the login page or display a success message
            $message = '<div class="success text-[#859F3F] mb-4"><p>Your password has been updated successfully.</p><a class="green-btn mt-4" href="' . $login_page . '">Go to log in page</a></div>';
            $show_form = false;
        }
    }
}
?>

<div class="grid col-gap-10 grid-cols-6 mt-8">
    <div class="col-span-full lg:col-span-3">

        <?php
            if($message) {
                echo $message;
            }
        ?>
        <?php if($show_form): ?>
            <form class="col-span-full lg:col-span-3" action="<?php echo esc_url( add_query_arg(['key' => isset($_GET['key']) ? $_GET['key'] : '', 'login' => isset($_GET['login']) ? $_GET['login'] : ''], $_SERVER['REQUEST_URI'])); ?>" method="post" x-data="{ password: '', password_check: '', passwordsMatch() { return this.password === this.password_check; } }">
            <p>
                <label for="password"><?php echo _e('Choose new password', "EnergyPLAN") ?></label>
                <input type="password" name="password" id="set-account-password" minlength="8" required x-model="password">
            </p>
            <p>
                <label for="password_check"><?php echo _e('Repeat password', "EnergyPLAN") ?></label>
                <input type="password" name="password_check" id="set-account-password_check" required x-model="password_check">
                <template x-if="password && password_check && !passwordsMatch()">
                    <p class="text-red-500"><?php _e('Passwords do not match.', "EnergyPLAN") ?></p>
                </template>
            </p>
            <p>
                <input class="blue-btn" type="submit" value="<?php _e('Update password', 'EnergyPLAN') ?>" :disabled="!passwordsMatch()">
            </p>
        </form>
        <?php endif; ?>
    </div>
</div>