<?php

function restrict_admin_access() {
    if (!current_user_can('administrator')) {
        // If the user is not an administrator, redirect them
        wp_redirect(home_url());
        exit;
    }
}
add_action('admin_init', 'restrict_admin_access');

function login_failed() {
    $login_page = get_field('login_side', 'option');
    wp_redirect($login_page . '?login=failed');
    exit;
}

add_action('wp_login_failed', 'login_failed');

function verify_username_password($user, $username, $password) {
    $login_page = get_field('login_side', 'option');
    if ($username == "" || $password == "") {
        wp_redirect($login_page . "?login=failed");
        exit;
    }
}
add_filter('authenticate', 'verify_username_password', 1, 3);





add_action('init', 'custom_password_update');
function custom_password_update() {
    $user_id = get_current_user_id();
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['password'], $_POST['password_check'])) {
        $password = $_POST['password'];
        $password_check = $_POST['password_check'];

        if($password && ($password === $password_check)) {
            if (!is_wp_error($user_id)) {
                wp_set_password($password, $user_id);

                // Optionally, re-authenticate the user
                wp_clear_auth_cookie();
                wp_set_current_user($user_id);
                wp_set_auth_cookie($user_id);

                $redirect_url = get_field('my_profile_page', 'option'); // Redirect to home or a specific page
                wp_redirect($redirect_url . '?password_updated=true');
                exit;

            } else {
                $redirect_url = get_field('my_profile_page', 'option'); // Redirect to home or a specific page
                wp_redirect($redirect_url . '?password_updated=false');
                exit;
            }
        }
    }
}

add_action('init', 'user_information_update');
function user_information_update() {
    $user_id = get_current_user_id();
    $userInfo = get_userdata($user_id);
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['firstname'], $_POST['lastname'], $_POST['email'], $_POST['organization'], $_POST['country'])) {
        $firstname = sanitize_text_field($_POST['firstname']);
        $lastname = sanitize_text_field($_POST['lastname']);
        $email = sanitize_email($_POST['email']);
        $organization = sanitize_text_field($_POST['organization']);
        $country = sanitize_text_field($_POST['country']);

        if ($email && $firstname && $lastname  && $organization) {
            if (email_exists($email) == false || $email == $userInfo->user_email) {
                wp_update_user([
                    'ID' => $user_id,
                    'first_name' => $firstname,
                    'last_name' => $lastname,
                    'user_email' => $email,
                    // Add additional user meta such as 'organization' if needed
                ]);
                if (!is_wp_error($user_id)) {
                    update_field('organization', $organization, 'user_' . $user_id);
                    update_field('country', $country, 'user_' . $user_id);
                }

                $redirect_url = get_field('my_profile_page', 'option'); // Redirect to home or a specific page
                wp_redirect($redirect_url . '?information_updated=true');
                exit;

            } else {
                $redirect_url = get_field('my_profile_page', 'option'); // Redirect to home or a specific page
                wp_redirect($redirect_url . '?information_updated=false');
                exit;
            }
        }
    }
}