const chokidar = require('chokidar');
const exec = require('child_process').exec;
const fs = require('fs');
const path = require('path');

// Watch for PHP file changes in any subdirectory under blocks
chokidar.watch('./blocks/**/*.php').on('change', (path) => {
    console.log(`Detected change in ${path}`);
    const folderPath = path.substring(0, path.lastIndexOf("/"));

    // Generate a temporary Tailwind config
    const tempConfig = {
        content: [path], // Only include the changed PHP file
        theme: {
            extend: {},
        },
        plugins: [],
    };

    const tempConfigPath = `${folderPath}/tailwind.temp.config.js`;
    fs.writeFileSync(tempConfigPath, `module.exports = ${JSON.stringify(tempConfig)}`);

    // Run Tailwind CLI with the temporary config
    const command = `npx tailwindcss -i ${folderPath}/input.css -o ${folderPath}/output.css --config ${tempConfigPath}`;
    exec(command, (error, stdout, stderr) => {
        if (error) {
            console.error(`exec error: ${error}`);
            return;
        }
        console.log(`stdout: ${stdout}`);
        console.error(`stderr: ${stderr}`);

        // Remove the temporary config file
        fs.unlinkSync(tempConfigPath);
    });
});

// Define a function to build Tailwind CSS
function buildTailwind(contentPaths, outputPath) {
    const baseConfig = require('./tailwind.config.js');

    // Modify the content paths of the base config
    const tempConfig = { ...baseConfig, content: contentPaths };

    // Path for the temporary Tailwind config file
    const tempConfigPath = path.join(outputPath, 'tailwind.temp.config.js');
    fs.writeFileSync(tempConfigPath, `module.exports = ${JSON.stringify(tempConfig, null, 2)}`);

    // Adjust the input and output paths as needed
    const command = `npx tailwindcss -i ${path.join(outputPath, 'input.css')} -o ${path.join(outputPath, 'output.css')} --config ${tempConfigPath}`;
    exec(command, (error, stdout, stderr) => {
        if (error) {
            console.error(`exec error: ${error}`);
            return;
        }
        console.log(`stdout: ${stdout}`);
        console.error(`stderr: ${stderr}`);

        fs.unlinkSync(tempConfigPath); // Clean up the temporary config file
    });
}

// Watch for changes in PHP files in the root directory
chokidar.watch(['./*.php', './src/css/input.css']).on('change', (changedFilePath) => {
    console.log(`Detected change in ${changedFilePath}`);

    // Specify all PHP files in the root directory as content paths
    const contentPaths = fs.readdirSync('.')
        .filter(file => file.endsWith('.php'))
        .map(file => `./${file}`);

    const outputPath = './src/css/'; // The directory where input.css and output.css are located
    buildTailwind(contentPaths, outputPath);
});

// Additional watchers (e.g., for the blocks directory) can be added here following a similar pattern




